/*
	STPlot Defaults
	Created by Stilianos Louca on 10.2011
	
	Normally You should not need to modify this.
*/


#ifndef STPLOT_DEFAULTS
#define STPLOT_DEFAULTS


namespace ST{

#define ST_GNUPLOT_IDEAL_VERSION "4.6"
#define ST_GNUPLOT_COMMENT_PREFIX "#"
#define ST_DEFAULT_ST_GNUPLOT_HISTOGRAM_GAP 1.0
#define ST_DEFAULT_ST_GNUPLOT_GRIDSIZE 70
#define ST_DEFAULT_ST_GNUPLOT_GRIDNORM 16.0 //see gnuplot 'help dgrid3d' on 'qnorm'
#define ST_DEFAULT_TERMINAL_WIDTH 	400.0	//in pixels
#define ST_DEFAULT_TERMINAL_HEIGHT 	363.0 	//in pixels
#define ST_DEFAULT_EPS_WIDTH		3.3		//in inches
#define ST_DEFAULT_EPS_HEIGHT		3.0		//in inches
#define ST_DEFAULT_MAX_EPS_WIDTH	100.0	//in inches, for the entire MultiPlot. issues arise when EPS gets too large
#define ST_DEFAULT_MAX_EPS_HEIGHT	100.0	//in inches, for the entire MultiPlot. issues arise when EPS gets too large
#define ST_DEFAULT_PDF_WIDTH		3.3		//in inches
#define ST_DEFAULT_PDF_HEIGHT		3.0		//in inches
#define ST_DEFAULT_SVG_WIDTH 		400.0	//in pixels
#define ST_DEFAULT_SVG_HEIGHT 		363.0 	//in pixels
#define ST_DEFAULT_PLOT_H_SPACING	0.05	// relative to plot width
#define ST_DEFAULT_PLOT_V_SPACING	0.05	// relative to plot height
#define ST_DEFAULT_GRID_COLORING_TYPE GridColoringTypeMean
#define ST_DEFAULT_GRID_SMOOTHING_TYPE GridSmoothingTypeEuclidean
#define ST_DEFAULT_VECTOR_HEAD_STYLE VectorHeadStyleFilledArrow
#define ST_DEFAULT_CONTOUR_PLACEMENT ContourPlacementBottom
#define ST_DEFAULT_VECTOR_HEAD_SIZE 0.3 //relative to maximum possible vector head size (which depends on vector length) 
#define ST_DEFAULT_INDIVIDUAL_CONTOURS true
#define ST_DEFAULT_NETWORK_NODE_COVERAGE 0.01 //fraction of plot area to be covered by all nodes together (in network plots)
#define ST_DEFAULT_WRITE_COMPOSITE_PLOTS_MULTILINE true
#define ST_DEFAULT_MAX_GREY_FOR_STACKED_CENTILE_PLOTS 0.95

//plot margins of single plots
#define ST_DEFAULT_RELATIVE_LMARGIN 0.2					//in units of single plot size.
#define ST_DEFAULT_RELATIVE_RMARGIN 0.1					//in units of single plot size.
#define ST_DEFAULT_RELATIVE_BMARGIN 0.2					//in units of single plot size.
#define ST_DEFAULT_RELATIVE_TMARGIN 0.2					//in units of single plot size.
#define ST_DEFAULT_RELATIVE_COLORBOX_RMARGIN	0.05	//in units of single plot size.
#define ST_DEFAULT_RELATIVE_COLORBOX_WIDTH 		0.03	//in units of single plot size. Box placement is vertical along the right side of the plot.
#define ST_DEFAULT_RELATIVE_COLORBOX_DIST 		0.01 	//x-distance to right plot margin in units of single plot size.

//aspect ratio for multiplots
#define ST_DEFAULT_MULTIPLOT_RATIO 1.333	//optimal aspect ratio for multiplots (columns over rows)
#define ST_DEFAULT_MIN_MULTIPLOT_RATIO 0.5 	//minimum aspect ratio for multiplots (columns over rows)
#define ST_DEFAULT_MAX_MULTIPLOT_RATIO 3 	//maximum aspect ratio for multiplots (columns over rows)

//Labels
#define ST_DEFAULT_ZLABEL_MAX_SIZE_BEFORE_ROTATION 	3
#define ST_DEFAULT_LABEL_HEIGHT_TERM 				15
#define ST_DEFAULT_LABEL_HEIGHT_SVG 				15
#define ST_DEFAULT_LABEL_HEIGHT_EPS 				0.1
#define ST_DEFAULT_BACKGROUND_TAG					20

//Default font sizes
#define ST_DEFAULT_AQUATERM_FONTSIZE				14
#define ST_DEFAULT_SVG_FONTSIZE						9

// size adjustments for heatmap plots (needed if many rows or columns are plotted)
// relative to default plot size
// assumes that these corrections are about the same for different plot types (e.g. terminal, PDF..)
// only valid for default font sizes
#define ST_DEFAULT_HEATMAP_CORRECTION_PER_ROW 				(1.0/12.0)
#define ST_DEFAULT_HEATMAP_CORRECTION_PER_COLUMN 			(1.0/11)
#define ST_DEFAULT_HEATMAP_CORRECTION_PER_ROW_NAME_CHAR		(1.0/39.0)
#define ST_DEFAULT_HEATMAP_CORRECTION_PER_COLUMN_NAME_CHAR	(1.0/36.0)
	
//gnuplot installation paths and default plot terminals
#if defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__TOS_WIN__)
	#define ST_DEFAULT_GNUPLOT_PATH "C:/program files/gnuplot/bin/pgnuplot.exe"
	#define ST_DEFAULT_TERM "Windows"
#elif defined(__APPLE__)
	#define ST_DEFAULT_GNUPLOT_PATH "/usr/local/bin/gnuplot"
	#define ST_DEFAULT_TERM "aqua dashed enhanced"
#elif defined(unix) || defined(__unix) || defined(__unix__)
	#define ST_DEFAULT_GNUPLOT_PATH "/usr/bin/gnuplot"
	#define ST_DEFAULT_TERM "x11 dashed enhanced"
#else
	#define ST_DEFAULT_GNUPLOT_PATH "gnuplot"
	#define ST_DEFAULT_TERM "x11 dashed enhanced"
#endif

#define ST_CORRECT_EPS_BLURS true // try to correct blurred heatmap EPS (and PDF) using 3rd party command line tools

#define SUPPRESS_GNUPLOT_ERRORS true // suppress all errors generated by gnuplot when executing a plot script

//some internal definitions
#define ST_DEFAULT_PERSIST_PLOT true
#define ST_GNUPLOT_RGB_FUNCTION_NAME "rgb"
#define ST_GNUPLOT_INVERSE_RGB_FUNCTION_NAME_RED "irgb_r"
#define ST_GNUPLOT_INVERSE_RGB_FUNCTION_NAME_GREEN "irgb_g"
#define ST_GNUPLOT_INVERSE_RGB_FUNCTION_NAME_BLUE "irgb_b"
#define ST_DEFAULT_MAX_VECTOR_LENGTH 0.05 //relative to whole plot
#define ST_DEFAULT_ASPECT_RATIO_RELATIVE_TOLLERANCE 0.1
#define ST_DEFAULT_PLOT_RANGE_TOLLERANCE 0.001 //used to fix some artifact problems with gnuplot ranges


}//end of namespace ST

#endif
